PrintColorStyle class

Constructors

PrintColorStyle({Color? background, bool bold = false, Color foreground = Colors.blue, bool italic = false, String prefix = "", bool underline = false})
const

Properties

background → Color?
final
bold → bool
final
foreground → Color
final
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
prefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underline → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited